@@ -87,7 +87,7 @@ KCMFilter::KCMFilter(QWidget *parent, const QVariantList &)
 
     QWidget *searchBox = new QWidget;
     QHBoxLayout *searchBoxHBoxLayout = new QHBoxLayout(searchBox);
-    searchBoxHBoxLayout->setMargin(0);
+    searchBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     searchBoxHBoxLayout->setSpacing(-1);
     new QLabel(i18n("Search:"), searchBox);
 
@@ -106,7 +106,7 @@ KCMFilter::KCMFilter(QWidget *parent, const QVariantList &)
 
     QWidget *buttonBox = new QWidget;
     QHBoxLayout *buttonBoxHBoxLayout = new QHBoxLayout(buttonBox);
-    buttonBoxHBoxLayout->setMargin(0);
+    buttonBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(buttonBox);
 
     container->setLayout(vbox);
@@ -152,7 +152,7 @@ KCMFilter::KCMFilter(QWidget *parent, const QVariantList &)
 
     QWidget *impexpBox = new QWidget;
     QHBoxLayout *impexpBoxHBoxLayout = new QHBoxLayout(impexpBox);
-    impexpBoxHBoxLayout->setMargin(0);
+    impexpBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *impexpLabel = new QLabel(i18n("<qt>More information on "
                                           "<a href=\"importhelp\">import format</a>, "
                                           "<a href=\"exporthelp\">export format</a>"), impexpBox);
@@ -411,7 +411,7 @@ void KCMFilter::insertFilter()
         // So we search again to locate the just-added item.
         //int id = mListBox->count()-1;
         QListWidgetItem *newItem = mListBox->findItems(newFilter, Qt::MatchCaseSensitive | Qt::MatchExactly).first();
-        if (newItem != 0) {
+        if (newItem != nullptr) {
             int id = mListBox->row(newItem);
 
             mListBox->item(id)->setSelected(true);
@@ -509,7 +509,7 @@ void AutomaticFilterModel::defaults()
 
 QModelIndex AutomaticFilterModel::index(int row, int column, const QModelIndex & /*parent*/) const
 {
-    return createIndex(row, column, (void *)NULL);
+    return createIndex(row, column, (void *)nullptr);
 }
 
 QModelIndex AutomaticFilterModel::parent(const QModelIndex & /*index*/) const
